Wilfred API
===========

.. py:module:: wilfred.api.servers

.. warning::

    The API is currently not stable and should not be used.

``wilfred.api.servers``
-----------------------

.. py:class:: Servers

  .. automethod:: __init__
  .. automethod:: all
  .. automethod:: remove
  .. automethod:: console
  .. automethod:: install
  .. automethod:: kill
  .. automethod:: command
  .. automethod:: sync
  .. automethod:: rename

.. py:module:: wilfred.api.images

``wilfred.api.images``
----------------------

.. py:class:: Images

  .. automethod:: download
  .. automethod:: data_strip_non_ui
  .. automethod:: get_image
  .. automethod:: read_images